@@ -1,9 +1,10 @@
 //const sha1 = require('js-sha1');
 exports.render = function (req, res) {
-    res.render('index', {
+    /*res.render('index', {
         'title': "Hello",
         'message': "Hello First Viwer"
-    });
+    });*/
+    res.send("Hello");
 
 }
 
